@@ -1,8 +1,7 @@
 require 'spec_helper'
 
 describe 'openstacklib::policy' do
-
-  shared_examples_for 'openstacklib::policy' do
+  shared_examples 'openstacklib::policy' do
     context 'with basic configuration' do
       let :params do
         {
@@ -16,25 +15,23 @@ describe 'openstacklib::policy' do
         }
       end
 
-      it 'configures the proper policy' do
-        is_expected.to contain_openstacklib__policy__base('foo').with(
-          :file_path => '/etc/nova/policy.json',
-          :key       => 'context_is_admin',
-          :value     => 'foo:bar'
-        )
-      end
+      it { should contain_openstacklib__policy__base('foo').with(
+        :file_path => '/etc/nova/policy.json',
+        :key       => 'context_is_admin',
+        :value     => 'foo:bar'
+      )}
     end
   end
 
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'openstacklib::policy'
+      it_behaves_like 'openstacklib::policy'
     end
   end
 
